@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12819 2021-03-30 02:12:19Z Becca $
+# $Id: __init__.py 12821 2021-03-30 10:40:58Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-03-30 10:12:19 +0800 (Tue, 30 Mar 2021) $
-# $Revision: 12819 $
+# $Date: 2021-03-30 18:40:58 +0800 (Tue, 30 Mar 2021) $
+# $Revision: 12821 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
@@ -25,7 +25,7 @@ class settings(object):
         "cms_oscar/Latest.html"
     ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE = \
         "cms_oscar/Offer.html"
-    ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE = \
+    ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE = \
         "cms_oscar/Bestseller.html"
 
     ZEPHYRUS_OSCAR_FEATURED_TEMPLATES = [
@@ -40,7 +40,7 @@ class settings(object):
         (ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE, _("Default")),
     ]
 
-    ZEPHYRUS_OSCAR_BESTSELLER__TEMPLATES = [
+    ZEPHYRUS_OSCAR_BESTSELLER_TEMPLATES = [
         (ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE, _("Default")),
     ]
 
