@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12225 2020-05-15 10:17:05Z Andy $
+# $Id: cms_plugins.py 12819 2021-03-30 02:12:19Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $ (last)
-# $Date: 2020-05-15 18:17:05 +0800 (Fri, 15 May 2020) $
-# $Revision: 12225 $
+# $Author: Becca $ (last)
+# $Date: 2021-03-30 10:12:19 +0800 (Tue, 30 Mar 2021) $
+# $Revision: 12819 $
 
 from django.db.models import Count
 from django.template.loader import select_template
@@ -25,8 +25,8 @@ from oscar.core.loading import get_model
 
 from Zephyrus.cms_oscar import settings 
 from Zephyrus.cms_oscar.models import (
-    OscarFeatured, OscarLatest, OscarOffer, OR, AND)
-from Zephyrus.cms_oscar.forms import OscarFeaturedForm, OscarLatestForm
+    OscarFeatured, OscarLatest, OscarOffer, OscarBestSeller, OR, AND)
+from Zephyrus.cms_oscar.forms import OscarFeaturedForm, OscarLatestForm, OscarBestSellerForm
 
 
 ProductRecord = get_model('analytics', 'ProductRecord')
@@ -161,6 +161,69 @@ class LatestPlugin(CMSPluginBase):
         
         return context
 
+class BestSellerPlugin(CMSPluginBase):
+    model = OscarBestSeller
+    module = "Shop"
+    name = "BestSeller Products"
+    render_template = settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE
+    form = OscarBestSellerForm
+
+    def get_render_template(self, context, instance, placeholder):
+        return select_template([
+            instance.renderTemplate,
+            settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE,
+        ])
+
+    def render(self, context, instance, placeholder):
+        catagories = instance.catagory.all()
+        query = None
+
+        # category
+        if catagories:
+            for c in catagories:
+                if query:
+                    if instance.filterMethod == OR:
+                        query = query | Q(product__categories__id=c.id)
+                    else:
+                        query = query & Q(product__categories__id=c.id)
+                else:
+                    query = Q(product__categories__id=c.id)
+
+        # tag
+        if hasTags:
+            if instance.tag:
+                tags = [int(t) for t in instance.tag.split(",")]
+            else:
+                tags = []
+
+            if tags:
+                for t in tags:
+                    if query:
+                        if instance.filterMethod == OR:
+                            query = query | Q(product__tags__id=t)
+                        else:
+                            query = query & Q(product__tags__id=t)
+                    else:
+                        query = Q(product__tags__id=t)
+
+        if query:
+            queryset = ProductRecord.objects.filter(query)
+        else:
+            queryset = ProductRecord.objects.all()
+
+        if queryset.count() >= instance.limit:
+            bestSeller = \
+                queryset.order_by('-num_purchases')[:instance.limit]
+        else:
+            bestSeller = queryset.order_by('-num_purchases')
+        products = [x.product for x in bestSeller]
+        context.update({
+            'products': products,
+        })
+        
+        return context
+
+
 class OfferPlugin(CMSPluginBase):
     model = OscarOffer
     module = "Shop"
