@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 9913 2017-04-24 13:07:32Z Lavender $
+# $Id: admin.py 9948 2017-05-07 06:08:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,16 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-24 21:07:32 +0800 (週一, 24 四月 2017) $
-# $Revision: 9913 $
+# $Date: 2017-05-07 14:08:11 +0800 (Sun, 07 May 2017) $
+# $Revision: 9948 $
 
 from django.contrib import admin
 
 from Zephyrus.landing.models import Email
 
-admin.site.register(Email)
+class EmailAdmin(admin.ModelAdmin):
+    list_display = (
+        'email', 'fromUrl', 'date',
+    )
+
+admin.site.register(Email, EmailAdmin)
